@@ -1,18 +1,21 @@
 #!/usr/bin/env python3
+"""AAFTF main framework for submodule run."""
 
 # note structure of code taken from poretools
 # https://github.com/arq5x/poretools/blob/master/poretools/poretools_main.py
 
-import sys
 import argparse as ap
-from AAFTF.utility import status
+import sys
 
 # AAFTF imports
 from AAFTF.__version__ import __version__  # noqa: E402
+from AAFTF.utility import status
+
 myversion = __version__
 
 
 def run_subtool(parser, args):
+    """Run the subtool of the AAFTF pipeline."""
     if args.command == 'runall':
         print("runall")
     elif args.command == 'trim':
@@ -45,21 +48,24 @@ def run_subtool(parser, args):
 
 
 class ArgumentParserWithDefaults(ap.ArgumentParser):
+    """Argument parsing top level."""
     def __init__(self, *args, **kwargs):
-        super(ArgumentParserWithDefaults, self).__init__(*args, **kwargs)
+        """Init function for ArgumentParser."""
+        super().__init__(*args, **kwargs)
         self.add_argument("-q", "--quiet",
                           help="Do not output warnings to stderr",
                           action="store_true",
                           dest="quiet")
 
     def error(self, message):
+        """Error message passing from argument passing."""
         sys.stderr.write('error: %s\n' % message)
         self.print_help()
         sys.exit(2)
 
 
 def main():
-
+    """Main function for AAFTF module submenus."""
     #########################################
     # create the top-level parser
     #########################################
@@ -101,7 +107,7 @@ def main():
 
     parser_trim = subparsers.add_parser(
         'trim',
-        description="This comamnd trims reads in FASTQ format to " +
+        description="This command trims reads in FASTQ format to " +
         "remove low quality reads and trim adaptor sequences",
         help='Trim FASTQ input reads')
 
@@ -183,6 +189,9 @@ def main():
     parser_trim.add_argument('--merge', action='store_true',
                              help="Merge paired end reads when running fastp")
 
+    parser_trim.add_argument('--prefix', type=str, required=False,
+                             help="Prefix for outfiles")
+
     tool_group = parser_trim.add_mutually_exclusive_group(required=False)
 
     tool_group.add_argument('--trimmomatic', '--jar',
@@ -278,7 +287,7 @@ def main():
     ##########
     # arguments
     # -i / --indir:  input dir
-    # -p / --prefix: in fastq reads and output prefix
+    # -o / --out: in fastq reads and output prefix
     # -a / --screen_accessions: screening sequence GenBank accessions
     # -u / --screen_urls: screening sequence URLs (fasta format)
     # --debug: print debug messages and do no remove contamdb BAM file
@@ -426,10 +435,12 @@ def main():
     parser_asm.add_argument('--tmpdir', type=str,
                             required=False,
                             help="Assembler temporary dir")
+
     parser_asm.add_argument('--assembler_args',
                             action='append',
                             required=False,
                             help="Additional SPAdes/Megahit arguments")
+
     parser_asm.add_argument('--haplocontigs',
                             dest='haplocontigs',
                             default=False,
@@ -479,6 +490,10 @@ def main():
         required=False,
         help="Percent Identity cutoff for vecscreen adaptor matches")
 
+    parser_vecscreen.add_argument(
+        '--prefix', type=str,
+        required=False, help="Prefix for tempfiles")
+
     parser_vecscreen.add_argument(
         '-w', '--workdir', '--tmpdir',
         type=str,
@@ -530,6 +545,10 @@ def main():
         required=True,  # think about sensible replacement in future
         help="Output sourmash cleaned assembly")
 
+    parser_sour.add_argument(
+        '--prefix', type=str,
+        required=False, help="Prefix for tempfiles")
+
     parser_sour.add_argument('-l', '--left', required=False,
                              help="Left (Forward) reads")
 
@@ -728,6 +747,10 @@ def main():
         required=False,
         help="Temporary directory to store datafiles for processes")
 
+    parser_pilon.add_argument(
+        '--prefix', type=str,
+        required=False, help="Prefix for readfiles")
+
     parser_pilon.add_argument('--pipe', action='store_true',
                               help="AAFTF is running in pipeline mode")
 
@@ -769,7 +792,8 @@ def main():
     # arguments
     # -i / --input: input assembly file
     # -r / --report: report file (otherwise stdout)
-    # --tmpdir
+    # -t / --telomere_monomer: telomere repeat monomer pattern (default=[TAA[C]+])
+    # -n / --telomere_n_repeats: Minimum number of repeats of telomere monomer (default=2)
 
     parser_assess = subparsers.add_parser(
         'assess',
@@ -787,6 +811,15 @@ def main():
         help='Filename to save report information otherwise ' +
         'will print to stdout')
 
+    parser_assess.add_argument(
+        '-t', '--telomere_monomer', type=str,
+        help='Telomere repeat monomer to search for. default(TAA[C]+)',
+        default='TAA[C]+')
+
+    parser_assess.add_argument(
+        '-n', '--telomere_n_repeat', type=int, default=2,
+        help='Telomere minimum number of monomer repeats. (default 2)')
+
     ##########
     # pipeline run it all
     ##########
@@ -899,9 +932,9 @@ def main():
     args = parser.parse_args()
 
     try:
-        status('Running AAFTF v{:}'.format(myversion))
+        status(f'Running AAFTF v{myversion}')
         args.func(parser, args)
-    except IOError as e:
+    except OSError as e:
         if e.errno != 32:  # ignore SIGPIPE
             raise
 
